@@ -7,7 +7,7 @@ use Carp;
 use Dancer2::Plugin;
 use Class::Load qw(try_load_class);
 
-our $VERSION = '0.305';
+our $VERSION = '0.306';
 
 my $settings;
 
@@ -608,7 +608,7 @@ on_plugin_import {
                 my $dsl = shift;
 
                 if(logged_in_user($dsl)) {
-                    $dsl->redirect($dsl->params->{return_url} || $userhomepage);
+                    $dsl->redirect($dsl->request->params->{return_url} || $userhomepage);
                 }
 
                 $dsl->response->status(401);
@@ -801,7 +801,7 @@ Henk van Oers (GH #8, #13).
 
 Andrew Beverly (GH #6, #7, #17).
 
-Gabor Szabo (GH #11, #16).
+Gabor Szabo (GH #11, #16, #18).
 
 =head1 LICENSE AND COPYRIGHT
 
